#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchComponentGroup(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchComponentGroup
                | 
                | Represents a temporary group of schematic objects for component
                | placement.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_component_group = com_object

    def add_member(self, i_cntbl_to_add: SchAppConnectable) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddMember(SchAppConnectable iCntblToAdd)
                | 
                |     Add a member to the component group.
                | 
                |     Parameters:
                | 
                |         iCntblToAdd
                |             The application connectable to be added to the group
                |
                |     Example:
                |
                |          Dim objThisIntf As SchComponentGroup
                |          Dim objArg1 As SchAppConnectable
                |           ...
                |          objThisIntf.AddMemberobjArg1

        :param SchAppConnectable i_cntbl_to_add:
        :rtype: None
        """
        return self.sch_component_group.AddMember(i_cntbl_to_add.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_member'
        # # vba_code = """
        # # Public Function add_member(sch_component_group)
        # #     Dim iCntblToAdd (2)
        # #     sch_component_group.AddMember iCntblToAdd
        # #     add_member = iCntblToAdd
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_members(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListMembers() As SchListOfObjects
                | 
                |     List all connectable members in the group.
                | 
                |     Parameters:
                | 
                |         oLGRR
                |             A list of connectables. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponentGroup
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListMembers

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_component_group.ListMembers())

    def remove_member(self, i_cntbl_to_remove: SchAppConnectable) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveMember(SchAppConnectable iCntblToRemove)
                | 
                |     Remove a member to the component group.
                | 
                |     Parameters:
                | 
                |         iCntbleToRemove
                |             The application connectable to be removed from the group
                |
                |     Example:
                |
                |          Dim objThisIntf As SchComponentGroup
                |          Dim objArg1 As SchAppConnectable
                |           ...
                |          objThisIntf.RemoveMemberobjArg1

        :param SchAppConnectable i_cntbl_to_remove:
        :rtype: None
        """
        return self.sch_component_group.RemoveMember(i_cntbl_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_member'
        # # vba_code = """
        # # Public Function remove_member(sch_component_group)
        # #     Dim iCntblToRemove (2)
        # #     sch_component_group.RemoveMember iCntblToRemove
        # #     remove_member = iCntblToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchComponentGroup(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class WITextAccessEi(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     WITextAccessEI

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.wi_text_access_ei = com_object

    def get_geom_referred_by_annotation(
            self,
            i_opor_act: int,
            i_assigned_ei_index: int,
            i_assignment_type: int,
            io_point_geom: AnyObject
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetGeomReferedByAnnotation(short iOporAct,
                | long iAssignedEIIndex,
                | ItemAssignmentType iAssignmentType,
                | CATBaseDispatch ioPointGeom)
                | 
                |     Gets the underlying geometry associated to FTA Text Annotation, an
                |     Engineering Intent which is added as an item to operation or to a WIText
                |     activity.
                | 
                |     Parameters:
                | 
                |         iOpOrAcr
                |             Flag to know whether assignment of EI is at operation level or at
                |             activity level. Legal values:
                |             1 : Assignment is done at Operation level.
                |             0 : Assignment is done at Activity level. 
                |         iAssignedEIIndex
                |             Index of EIs either assigned to operation or to activity.
                |             
                |         iAssignmentType
                |             Type of the Assignment (Item to the Process) 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_opor_act:
        :param int i_assigned_ei_index:
        :param int i_assignment_type: enum item_assignment_type
        :param AnyObject io_point_geom:
        :rtype: None
        """
        return self.wi_text_access_ei.GetGeomReferedByAnnotation(
            i_opor_act,
            i_assigned_ei_index,
            i_assignment_type,
            io_point_geom.com_object
        )

    def __repr__(self):
        return f'WITextAccessEi(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_object_factory import SchAppObjectFactory
from pycatia.cat_sch_platform_interfaces.sch_base_factory import SchBaseFactory
from pycatia.cat_sch_platform_interfaces.sch_component import SchComponent
from pycatia.cat_sch_platform_interfaces.sch_grr import SchGRR
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.cat_sch_platform_interfaces.sch_session import SchSession
from pycatia.cat_sch_platform_interfaces.sch_temp_list_factory import SchTempListFactory
from pycatia.drafting_interfaces.drawing_root import DrawingRoot
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchematicRoot(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchematicRoot
                | 
                | Represents the top node of the schematic object tree.
                | From this node all the queries for lists of schematic objects can be made.
                | Furthermore, all the factories handles can be obtained through this
                | interface.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.schematic_root = com_object

    def get_appl_obj_fact_from_virtual_type(self, i_application_id: str) -> SchAppObjectFactory:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetApplObjFactFromVirtualType(CATBSTR iApplicationID) As
                | SchAppObjectFactory
                | 
                |     Returns the object factory for specific schematic
                |     application.
                | 
                |     Example:
                | 
                |           This example illustrates how to get the object factory of user
                |           defined virtual type. 
                |          User provides implementation to this type.
                |          
                | 
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchObjFact As SchAppObjectFactory
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Set objSchObjFact = objSchPlatformRoot.GetApplObjFactFromVirtualType("UserDefined")(

        :param str i_application_id:
        :rtype: SchAppObjectFactory
        """
        return SchAppObjectFactory(self.schematic_root.GetApplObjFactFromVirtualType(i_application_id))

    def get_application_object_factory(self, i_application_id: int) -> SchAppObjectFactory:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetApplicationObjectFactory(CatSchIDLApplicationID iApplicationID) As
                | SchAppObjectFactory
                | 
                |     Returns the object factory for specific schematic
                |     application.
                | 
                |     Example:
                | 
                |           This example illustrates how to get the object factory of Piping
                |          and Instrumentation Diagram application.
                |          
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchObjFact As SchAppObjectFactory
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Set objSchObjFact = objSchPlatformRoot.GetApplicationObjectFactory("CatSchIDLCATPID")(

        :param int i_application_id: enum cat_sch_idl_application_id
        :rtype: SchAppObjectFactory
        """
        return SchAppObjectFactory(self.schematic_root.GetApplicationObjectFactory(i_application_id))

    def get_comp_group_from_catalog(self, i_catalog_entry_name: str, i_ctlg_doc: Document) -> SchComponent:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCompGroupFromCatalog(CATBSTR iCatalogEntryName,
                | Document iCtlgDoc) As SchComponent
                | 
                |     Returns specific component group entry in a schematic component catalog
                |     document.
                | 
                |     Example:
                | 
                |           This example illustrates how to get a specific component group entry
                |           in a schematic component catalog document.
                |          
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchComponent As SchComponent
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Dim objCtlgDoc As Document
                |          Set objCtlgDoc = CATIA.Documents.Open ("Electrical_ANSI_PartFunctions.catalog")
                |          Set objSchComponent = objSchPlatformRoot.GetCompGroupFromCatalog ("JuncBox-TermBoard",objCtlgDoc)

        :param str i_catalog_entry_name:
        :param Document i_ctlg_doc:
        :rtype: SchComponent
        """
        return SchComponent(self.schematic_root.GetCompGroupFromCatalog(i_catalog_entry_name, i_ctlg_doc.com_object))

    def get_comp_symbol_from_catalog(self, i_catalog_entry_name: str, i_ctlg_doc: Document) -> SchGRR:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCompSymbolFromCatalog(CATBSTR iCatalogEntryName,
                | Document iCtlgDoc) As SchGRR
                | 
                |     Returns specific entry in a schematic component catalog
                |     document.
                | 
                |     Example:
                | 
                |           This example illustrates how to get a specific entry in a schematic
                |           component catalog document.
                |          
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchGRRComp As SchGRRComp
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Dim objCtlgDoc As Document
                |          Set objCtlgDoc = CATIA.Documents.Open ("PID_ANSI_Equipment.catalog")
                |          Set objSchGRRComp = objSchPlatformRoot.GetCompSymbolFromCatalog ("Blower",objCtlgDoc)

        :param str i_catalog_entry_name:
        :param Document i_ctlg_doc:
        :rtype: SchGRR
        """
        return SchGRR(self.schematic_root.GetCompSymbolFromCatalog(i_catalog_entry_name, i_ctlg_doc.com_object))

    def get_components(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetComponents() As SchListOfObjects
                | 
                |     Returns a list of schematic component instances under the
                |     root.
                | 
                |     Example:
                | 
                |           This example illustrates how to get the list of component instances
                |           from a schematic product document.
                |          
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchListComps As SchListOfObjects
                |          Set objoSchListComps = objSchPlatformRoot.GetComponents

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.schematic_root.GetComponents())

    def get_drawing(self) -> DrawingRoot:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDrawing() As DrawingRoot
                | 
                |     Retrieves the drawing root in the schematic document.
                | 
                |     Example:
                | 
                |           This example illustrates how to get the drawing of a schematic
                |           document.
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Dim objDrawRoot As DrawingRoot
                |          Set objDrawRoot = objSchPlatformRoot.GetDrawing

        :rtype: DrawingRoot
        """
        return DrawingRoot(self.schematic_root.GetDrawing())

    def get_drawing_standard(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDrawingStandard() As CatDrawingStandard
                |
                |     Get the drawing standard.
                |
                |     Example:
                |
                |           This example illustrates how to get the drafting standard of a
                |           schematic document.
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchLSymbols As SchListOfObjects
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          oDrwStd = objSchPlatformRoot.GetDrawingStandard

        :return: enum cat_drawing_standard
        :rtype: int
        """
        return self.schematic_root.GetDrawingStandard()

    def get_interface(self, i_interface_name: str, i_object: AnyObject) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetInterface(CATBSTR iInterfaceName,
                | AnyObject iObject) As AnyObject
                |
                |     Returns specific interface handle on a given object.
                |
                |     Example:
                |
                |           This example illustrates how to get a specific interface handle from
                |           a given object.
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchObjFact As SchAppObjectFactory
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Set objSchObjFact = SchPlatformRoot.GetApplicationObjectFactory("CatSchIDLCATPID")
                |          Set objSchObjFact2 = objSchPlatformRoot.GetInterface ("CATIASchAppObjectFactory2",SchObjFact)

        :param str i_interface_name:
        :param AnyObject i_object:
        :rtype: AnyObject
        """
        return AnyObject(self.schematic_root.GetInterface(i_interface_name, i_object.com_object))

    def get_ref_components(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRefComponents() As SchListOfObjects
                |
                |     Returns a list of schematic component references under the
                |     root.
                |
                |     Example:
                |
                |           This example illustrates how to get the list of component references
                |           from a schematic product document.
                |
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchListComps As SchListOfObjects
                |          Set objSchListComps = objSchPlatformRoot.GetRefComponents

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.schematic_root.GetRefComponents())

    def get_routes(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRoutes() As SchListOfObjects
                |
                |     Returns a list of schematic routes under the root.
                |
                |     Example:
                |
                |           This example illustrates how to get the list of routes from a
                |           schematic product document.
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchListRoutes As SchListOfObjects
                |          Set objSchListRoutes = objSchPlatformRoot.GetRoutes

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.schematic_root.GetRoutes())

    def get_sch_base_factory(self) -> SchBaseFactory:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSchBaseFactory() As SchBaseFactory
                |
                |     Returns schematic base object factory.
                |
                |     Example:
                |
                |           This example illustrates how to get the schematic base
                |           factory.
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchBaseFact As SchBaseFactory
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Set objSchBaseFact = objSchPlatformRoot.GetBaseFactory

        :rtype: SchBaseFactory
        """
        return SchBaseFactory(self.schematic_root.GetSchBaseFactory())

    def get_schematic_session(self) -> SchSession:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSchematicSession() As SchSession
                |
                |     Returns the schematic session the document containing the root is
                |     associated with.
                |
                |     Example:
                |
                |           This example illustrates how to get the schematic
                |           session.
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchSession As SchSession
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Set objSchSession = objSchPlatformRoot.GetSession

        :rtype: SchSession
        """
        return SchSession(self.schematic_root.GetSchematicSession())

    def get_temporary_list_factory(self) -> SchTempListFactory:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTemporaryListFactory() As SchTempListFactory
                |
                |     Returns the factory to create lists of various types. These lists will not
                |     be saved with the model.
                |
                |     Example:
                |
                |           This example illustrates how to get the list factory from a schematic
                |           product document.
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchList As SchTempListFactory
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Set objSchList = objSchPlatformRoot.GetTemporaryListFactory

        :rtype: SchTempListFactory
        """
        return SchTempListFactory(self.schematic_root.GetTemporaryListFactory())

    def get_unassociated_symbols(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUnassociatedSymbols() As SchListOfObjects
                |
                |     Returns a list of unassociated symbol.
                |
                |     Example:
                |
                |           This example illustrates how to get a list of unassociated
                |           symbol.
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchLSymbols As SchListOfObjects
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          Set objSchLSymbols = objSchPlatformRoot.GetUnassociatedSymbols

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.schematic_root.GetUnassociatedSymbols())

    def set_drawing_standard(self, i_drw_std: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDrawingStandard(CatDrawingStandard iDrwStd)
                |
                |     Set the drawing standard.
                |
                |     Example:
                |
                |           This example illustrates how to set the drafting standard of a
                |           schematic document.
                |
                |          Dim objSchPlatformRoot As SchematicRoot
                |          Dim objSchLSymbols As SchListOfObjects
                |          Dim objProductRoot As Product
                |          Set objProductRoot = CATIA.ActiveDocument.Product
                |          Set objSchPlatformRoot = objProductRoot.GetTechnologicalObject ("SchematicRoot")
                |          objSchPlatformRoot.SetDrawingStandard catISO

        :param int i_drw_std: enum cat_drawing_standard
        :rtype: None
        """
        return self.schematic_root.SetDrawingStandard(i_drw_std)

    def __repr__(self):
        return f'SchematicRoot(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.assembly_interfaces.assembly_feature import AssemblyFeature
from pycatia.mec_mod_interfaces.body import Body
from pycatia.product_structure_interfaces.product import Product


class AssemblyBoolean(AssemblyFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAssemblyInterfaces.AssemblyFeature
                |                         AssemblyBoolean
                | 
                | Represents the AssemblyBoolean object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.assembly_boolean = com_object

    @property
    def body(self) -> Body:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Body() As Body (Read Only)
                | 
                |     Returns the operating body.
                | 
                |     Example:
                |         The following example retrieves in opBody the operating body of the
                |         assembly boolean assemblyBool.
                | 
                |          Dim opBody As Body
                |          Set opBody = assemblyBool.Body

        :rtype: Body
        """

        return Body(self.assembly_boolean.Body)

    @property
    def body_component(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BodyComponent() As Product (Read Only)
                | 
                |     Returns the component containing the operating body.
                | 
                |     Example:
                |         The following example retrieves in opBodyComp the component that
                |         contains the operating body of the assembly boolean
                |         assemblyBool.
                | 
                |          Dim opBodyComp As Product
                |          Set opBodyComp = assemblyBool.BodyComponent

        :rtype: Product
        """

        return Product(self.assembly_boolean.BodyComponent)

    def __repr__(self):
        return f'AssemblyBoolean(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class DlNameSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         DLNameSettingAtt
                | 
                | Interface to handle the DLNames.
                | Role: This interface is implemented by a component which represents the
                | controller of the DLNames.
                | This interface defines:
                | 
                |     A method to set each DLName
                |     A method to get the value of each DLName
                |     A method to lock/unlock each parameter
                |     A method to retrieve the informations concerning each
                |     parameter
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dl_name_setting_att = com_object

    @property
    def dl_name_creation_right(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property DLNameCreationRight() As boolean
                | 
                |     Returns or set the right to create new DLNames.
                |     Role: Retrieves or set the right to create new DLNames.

        :return: bool
        """

        return self.dl_name_setting_att.DLNameCreationRight

    @dl_name_creation_right.setter
    def dl_name_creation_right(self, value):
        """
        :param bool value:
        """

        self.dl_name_setting_att.DLNameCreationRight = value

    @property
    def root_dl_name_creation_right(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property RootDLNameCreationRight() As boolean
                | 
                |     Returns or set the right to create new Root DLNames.
                |     Role: Retrieves or set the right to create new Root DLNames.

        :return: bool
        """

        return self.dl_name_setting_att.RootDLNameCreationRight

    @root_dl_name_creation_right.setter
    def root_dl_name_creation_right(self, value):
        """
        :param bool value:
        """

        self.dl_name_setting_att.RootDLNameCreationRight = value

    def get_dl_name(self, i_dl_name, o_real_name_unix, o_real_name_nt, o_father):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub GetDLName(CATBSTR iDLName,
                | CATBSTR oRealNameUnix,
                | CATBSTR oRealNameNT,
                | CATBSTR oFather)
                | 
                |     Retrieves the mapping between a logical name and the physical
                |     path.
                |     Role: Retrieves the mapping between a logical name and the physical
                |     path.
                | 
                |     Parameters:
                | 
                |         iDLName
                |             the logical name. 
                |         oRealNameUnix
                |             the real physical path corresponding to the logical name on Unix.
                |             
                |         oRealNameNT
                |             the real physical path corresponding to the logical name on
                |             Windows. 
                |         iFather
                |             if applicable the Name of the parent DLName 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_dl_name:
        :param str o_real_name_unix:
        :param str o_real_name_nt:
        :param str o_father:
        :return: None
        """
        return self.dl_name_setting_att.GetDLName(i_dl_name, o_real_name_unix, o_real_name_nt, o_father)

    def get_dl_name_creation_right_info(self, admin_level, o_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetDLNameCreationRightInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves the state of the parameter DLNameCreationRight.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :return: None
        """
        return self.dl_name_setting_att.GetDLNameCreationRightInfo(admin_level, o_locked)

    def get_dl_name_exp(self, i_dl_name, o_real_name_unix, o_real_name_nt, o_father):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub GetDLNameExp(CATBSTR iDLName,
                | CATBSTR oRealNameUnix,
                | CATBSTR oRealNameNT,
                | CATBSTR oFather)
                | 
                |     Retrieves the mapping between a logical name and the physical
                |     path.
                |     Role: Retrieves the mapping between a logical name and the physical path in
                |     a literal form.
                | 
                |     Parameters:
                | 
                |         iDLName
                |             the logical name. 
                |         oRealNameUnix
                |             the real physical path corresponding to the logical name on Unix.
                |             
                |         oRealNameNT
                |             the real physical path corresponding to the logical name on
                |             Windows. 
                |         iFather
                |             if applicable the Name of the parent DLName 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_dl_name:
        :param str o_real_name_unix:
        :param str o_real_name_nt:
        :param str o_father:
        :return: None
        """
        return self.dl_name_setting_att.GetDLNameExp(i_dl_name, o_real_name_unix, o_real_name_nt, o_father)

    def get_dl_name_info(self, i_dl_name, admin_level, o_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetDLNameInfo(CATBSTR iDLName,
                | CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves the state of the for a given DLName.
                |     Role: This information defines the state of the setting parameter and is
                |     made up of:
                | 
                |         The administration level that sets the current value or the value used
                |         to reset it
                |         The administration level that has locked the setting
                |         parameter.
                |         A flag to indicate whether the setting parameter was
                |         modified.
                | 
                |     Parameters:
                | 
                |         iDLName
                |             a DLname. 
                |         ioAdminLevel
                |             [inout] The administration leve that defines the value used when
                |             resetting the setting parameter.
                | 
                |             Legal values:
                | 
                |                 Default value if the DLName has never been defined in the
                |                 administration concatenation.
                |                 Admin Level n if the setting parameter has been
                |                 administered,
                |                 where n is an integer starting from 0 representing the rank of
                |                 the administration level.
                | 
                |         ioLocked
                |             [inout] A character string to indicate whether the parameter is
                |             locked and the level of administration where the locking has been
                |             proceeded.
                |             Legal values:
                | 
                |                 Locked at Admin Level n if the setting parameter is locked by
                |                 then administration level n,
                |                 where n is an integer starting from 0.
                |                 Upper Locked if the setting parameter is locked by the current
                |                 administration level
                |                 Unlocked if the setting parameter is not
                |                 locked
                | 
                |     Returns:
                |         True to indicate that the DLName value has been defined at the current
                |         administrator or user level. This is only possible with unlocked DLNames. False
                |         means that the DLName is inherited from the
                |         administration.

        :param str i_dl_name:
        :param str admin_level:
        :param str o_locked:
        :return: None
        """
        return self.dl_name_setting_att.GetDLNameInfo(i_dl_name, admin_level, o_locked)

    def get_dl_name_list(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetDLNameList() As CATSafeArrayVariant
                | 
                |     Retrieves the list of the DLNames.
                |     Role: Retrieves the list of the defined DLNames.
                | 
                |     Parameters:
                | 
                |         oTabDLName
                |             a CATSafeArrayVariant of CATBSTR of nb elements. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: tuple
        """
        return tuple(self.dl_name_setting_att.GetDLNameList())

    def get_dl_name_sub_list(self, i_dl_name):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetDLNameSubList(CATBSTR iDLName) As
                | CATSafeArrayVariant
                | 
                |     Retrieves the list of the Sub-DLNames.
                |     Role: Retrieves the list of the DLNames created in a given
                |     DLName.
                | 
                |     Parameters:
                | 
                |         iDLName
                |             The Father DLName. if iDLName=NULL all DLNames created at the root
                |             level are return. 
                |         oNbDLname
                |             The number of defined DLNames. 
                |         oTabDLName
                |             The array of DLNames 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_OUTOFMEMORY: on allocation failure
                |         E_FAIL: on other failures

        :param str i_dl_name:
        :return: tuple
        """
        return tuple(self.dl_name_setting_att.GetDLNameSubList(i_dl_name))

    def get_root_dl_name_creation_right_info(self, admin_level, o_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetRootDLNameCreationRightInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves the state of the parameter
                |     RootDLNameCreationRight.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :return: None
        """
        return self.dl_name_setting_att.GetRootDLNameCreationRightInfo(admin_level, o_locked)

    def remove_dl_name(self, i_dl_name):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub RemoveDLName(CATBSTR iDLName)
                | 
                |     Remove a logical name.
                |     Role: Remove a DLName in the current set if it is
                |     possible.
                | 
                |     Parameters:
                | 
                |         iDLName
                |             the logical name. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_dl_name:
        :return: None
        """
        return self.dl_name_setting_att.RemoveDLName(i_dl_name)

    def rename_dl_name(self, i_dl_name, i_new_name):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub RenameDLName(CATBSTR iDLName,
                | CATBSTR iNewName)
                | 
                |     Rename an existing DLName.
                |     Role: Rename a DLName in the current set if it is
                |     possible.
                | 
                |     Parameters:
                | 
                |         iDLName
                |             the logical name to rename. 
                |         iNewName
                |             the new logical name. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_dl_name:
        :param str i_new_name:
        :return: None
        """
        return self.dl_name_setting_att.RenameDLName(i_dl_name, i_new_name)

    def set_dl_name(self, i_dl_name, i_real_name_unix, i_real_name_nt, i_father, i_verif_directory):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetDLName(CATBSTR iDLName,
                | CATBSTR iRealNameUnix,
                | CATBSTR iRealNameNT,
                | CATBSTR iFather,
                | boolean iVerifDirectory)
                | 
                |     Sets the mapping between a logical name and the physical
                |     path.
                |     Role: Sets the value of the cache maximum size in Mo
                | 
                |     Parameters:
                | 
                |         iDLName
                |             the logical name. 
                |         oRealNameUnix
                |             the real physical path corresponding to the logical name on Unix.
                |             
                |         oRealNameNT
                |             the real physical path corresponding to the logical name on
                |             Windows. 
                |         iFather
                |             if applicable the Name of the parent DLName 
                |         iVerifDirectory
                |             if VerifDirectory is set the existence of the directory on the
                |             current platform will be check. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_dl_name:
        :param str i_real_name_unix:
        :param str i_real_name_nt:
        :param str i_father:
        :param bool i_verif_directory:
        :return: None
        """
        return self.dl_name_setting_att.SetDLName(
            i_dl_name,
            i_real_name_unix,
            i_real_name_nt,
            i_father,
            i_verif_directory
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dl_name'
        # # vba_code = """
        # # Public Function set_dl_name(dl_name_setting_att)
        # #     Dim iDLName (2)
        # #     dl_name_setting_att.SetDLName iDLName
        # #     set_dl_name = iDLName
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_dl_name_creation_right_lock(self, i_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetDLNameCreationRightLock(boolean iLocked)
                | 
                |     Locks or unlocks the parameter DLNameCreationRight.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        """
        return self.dl_name_setting_att.SetDLNameCreationRightLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dl_name_creation_right_lock'
        # # vba_code = """
        # # Public Function set_dl_name_creation_right_lock(dl_name_setting_att)
        # #     Dim iLocked (2)
        # #     dl_name_setting_att.SetDLNameCreationRightLock iLocked
        # #     set_dl_name_creation_right_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_dl_name_lock(self, i_dl_name, i_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetDLNameLock(CATBSTR iDLName,
                | boolean iLocked)
                | 
                |     Locks or unlocks the DLName.
                |     Role: Locks or unlocks the given DLName if the operation is allowed in the
                |     current administrated environment. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iDLname
                |             the DLname to be locked. 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_dl_name:
        :param bool i_locked:
        :return: None
        """
        return self.dl_name_setting_att.SetDLNameLock(i_dl_name, i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dl_name_lock'
        # # vba_code = """
        # # Public Function set_dl_name_lock(dl_name_setting_att)
        # #     Dim iDLName (2)
        # #     dl_name_setting_att.SetDLNameLock iDLName
        # #     set_dl_name_lock = iDLName
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_root_dl_name_creation_right_lock(self, i_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetRootDLNameCreationRightLock(boolean iLocked)
                | 
                |     Locks or unlocks the parameter RootDLNameCreationRight.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        """
        return self.dl_name_setting_att.SetRootDLNameCreationRightLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_root_dl_name_creation_right_lock'
        # # vba_code = """
        # # Public Function set_root_dl_name_creation_right_lock(dl_name_setting_att)
        # #     Dim iLocked (2)
        # #     dl_name_setting_att.SetRootDLNameCreationRightLock iLocked
        # #     set_root_dl_name_creation_right_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DlNameSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
    from pycatia.cat_sch_platform_interfaces.sch_app_connection import SchAppConnection


class SchAppConnector(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppConnector
                | 
                | Manage a schematic connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_connector = com_object

    def app_connect(self, i_cntr_to_connect: 'SchAppConnector') -> 'SchAppConnection':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppConnect(SchAppConnector iCntrToConnect) As
                | SchAppConnection
                | 
                |     Connect to an input connector.
                | 
                |     Parameters:
                | 
                |         iCntrToConnect
                |             A schematic connector object to connect to 
                |         oConnection
                |             Connection created 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnector
                |          Dim objArg1 As SchAppConnector
                |          Dim objArg2 As SchAppConnection
                |           ...
                |          Set objArg2 = objThisIntf.AppConnect(objArg1)

        :param SchAppConnector i_cntr_to_connect:
        :rtype: SchAppConnection
        """

        from pycatia.cat_sch_platform_interfaces.sch_app_connection import SchAppConnection
        return SchAppConnection(self.sch_app_connector.AppConnect(i_cntr_to_connect.com_object))

    def app_connect_branch(self, i_cntr_to_connect: 'SchAppConnector') -> 'SchAppConnection':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppConnectBranch(SchAppConnector iCntrToConnect) As
                | SchAppConnection
                | 
                |     Connect to an input connector for Branch.
                | 
                |     Parameters:
                | 
                |         iCntrToConnect
                |             A schematic connector object to connect to 
                |         oConnection
                |             Connection created 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppConnector
                |          Dim objArg1 As SchAppConnector
                |          Dim objArg2 As SchAppConnection
                |           ...
                |          Set objArg2 = objThisIntf.AppConnectBranch(objArg1)

        :param SchAppConnector i_cntr_to_connect:
        :rtype: SchAppConnection
        """

        from pycatia.cat_sch_platform_interfaces.sch_app_connection import SchAppConnection
        return SchAppConnection(self.sch_app_connector.AppConnectBranch(i_cntr_to_connect.com_object))

    def app_disconnect(self, i_cntr_to_dis_connect: 'SchAppConnector') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppDisconnect(SchAppConnector iCntrToDisConnect)
                | 
                |     Disconnect from an input connector.
                | 
                |     Parameters:
                | 
                |         iCntrToDisconnect
                |             A schematic connector object to disconnect from 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnector
                |          Dim objArg1 As SchAppConnector
                |           ...
                |          objThisIntf.AppDisconnectobjArg1

        :param SchAppConnector i_cntr_to_dis_connect:
        :rtype: None
        """
        return self.sch_app_connector.AppDisconnect(i_cntr_to_dis_connect.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_disconnect'
        # # vba_code = """
        # # Public Function app_disconnect(sch_app_connector)
        # #     Dim iCntrToDisConnect (2)
        # #     sch_app_connector.AppDisconnect iCntrToDisConnect
        # #     app_disconnect = iCntrToDisConnect
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_get_associated_connectable(self) -> 'SchAppConnectable':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppGetAssociatedConnectable() As SchAppConnectable
                | 
                |     Find the application object that owns this connector.
                | 
                |     Parameters:
                | 
                |         oConnectable
                |             An application object that the connector belongs to.
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnector
                |          Dim objArg1 As SchAppConnectable
                |           ...
                |          Set objArg1 = objThisIntf.AppGetAssociatedConnectable

        :rtype: SchAppConnectable
        """

        from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
        return SchAppConnectable(self.sch_app_connector.AppGetAssociatedConnectable())

    def app_is_cntr_connected(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppIsCntrConnected(boolean oBYes)
                | 
                |     Query whether the connector has been connected.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is connected 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnector
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppIsCntrConnectedbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_connector.AppIsCntrConnected(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_is_cntr_connected'
        # # vba_code = """
        # # Public Function app_is_cntr_connected(sch_app_connector)
        # #     Dim oBYes (2)
        # #     sch_app_connector.AppIsCntrConnected oBYes
        # #     app_is_cntr_connected = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_list_compatible_types(self) -> SchListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppListCompatibleTypes() As SchListOfBSTRs
                | 
                |     Find all the class types of connector that are compatible with this
                |     connector for connections.
                | 
                |     Parameters:
                | 
                |         oLCntrCompatClassTypes
                |             A list of all the class types of connectors that are compatible
                |             with this connector for connections. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnector
                |          Dim objArg1 As SchListOfBSTRs
                |           ...
                |          Set objArg1 = objThisIntf.AppListCompatibleTypes

        :rtype: SchListOfBSTRs
        """
        return SchListOfBSTRs(self.sch_app_connector.AppListCompatibleTypes())

    def app_list_connections(self, i_l_cntn_class_filter: SchListOfBSTRs) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppListConnections(SchListOfBSTRs iLCntnClassFilter) As
                | SchListOfObjects
                | 
                |     Find all the connections that include this connector.
                | 
                |     Parameters:
                | 
                |         oLCntnClassFilter
                |             A list of all the class types for filtering the output connection
                |             list. 
                |         oLConnections
                |             A list of connections that include this connector (members are
                |             CATISchAppConnection interface pointers). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnector
                |          Dim objArg1 As SchListOfBSTRs
                |          Dim objArg2 As SchListOfObjects
                |           ...
                |          Set objArg2 = objThisIntf.AppListConnections(objArg1)

        :param SchListOfBSTRs i_l_cntn_class_filter:
        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_app_connector.AppListConnections(i_l_cntn_class_filter.com_object))

    def app_ok_to_no_show_connected_cntr(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToNoShowConnectedCntr(boolean oBYes)
                | 
                |     Query whether it is OK to no show the connector after it is
                |     connected.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to no show. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnector
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToNoShowConnectedCntrbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_connector.AppOKToNoShowConnectedCntr(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_no_show_connected_cntr'
        # # vba_code = """
        # # Public Function app_ok_to_no_show_connected_cntr(sch_app_connector)
        # #     Dim oBYes (2)
        # #     sch_app_connector.AppOKToNoShowConnectedCntr oBYes
        # #     app_ok_to_no_show_connected_cntr = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppConnector(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchAppMultiImageMaster(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppMultiImageMaster
                | 
                | Interface to manage the master object in the Multi-Image-Object
                | concept.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_multi_image_master = com_object

    def app_add_image(self, i_image: SchAppConnectable) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppAddImage(SchAppConnectable iImage)
                | 
                |     Add an image for this master object.
                | 
                |     Parameters:
                | 
                |         iImage
                |             Pointer to the image to link this master to. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppMultiImageMaster
                |          Dim objImage As SchAppConnectable
                |           ...
                |          objThisIntf.AppAddImage objImage

        :param SchAppConnectable i_image:
        :rtype: None
        """
        return self.sch_app_multi_image_master.AppAddImage(i_image.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_add_image'
        # # vba_code = """
        # # Public Function app_add_image(sch_app_multi_image_master)
        # #     Dim iImage (2)
        # #     sch_app_multi_image_master.AppAddImage iImage
        # #     app_add_image = iImage
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_is_ok_to_create_image(
            self,
            i_image_doc: Document,
            o_b_yes: bool,
            o_nls_file_name: str,
            o_nls_file_key_to_message: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppIsOKToCreateImage(Document iImageDoc,
                | boolean oBYes,
                | CATBSTR oNLSFileName,
                | CATBSTR oNLSFileKeyToMessage)
                | 
                |     Check if OK to create an image of this master object.
                | 
                |     Parameters:
                | 
                |         iImageDoc
                |             Pointer to the document the image is in. 
                |         oBYes
                |             TRUE if this object is valid to be the master of a MIO
                |             relationship. 
                |         oNLSFileName
                |             File name for the NLS messages. 
                |         oNLSFileKeyToMessage
                |             Message key to the application specific diagnostics.
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppMultiImageMaster
                |          Dim objImageDoc As Document
                |          Dim bYes As boolean
                |          Dim strFileName As String
                |          Dim strFileKeyToMsg As String
                |           ...
                |          objThisIntf.AppIsOKToCreateImage
                |          objImageDoc,bYes,strFileName,strFileKeyToMsg

        :param Document i_image_doc:
        :param bool o_b_yes:
        :param str o_nls_file_name:
        :param str o_nls_file_key_to_message:
        :rtype: None
        """
        return self.sch_app_multi_image_master.AppIsOKToCreateImage(
            i_image_doc.com_object,
            o_b_yes,
            o_nls_file_name,
            o_nls_file_key_to_message
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_is_ok_to_create_image'
        # # vba_code = """
        # # Public Function app_is_ok_to_create_image(sch_app_multi_image_master)
        # #     Dim iImageDoc (2)
        # #     sch_app_multi_image_master.AppIsOKToCreateImage iImageDoc
        # #     app_is_ok_to_create_image = iImageDoc
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_list_images(self, i_l_filter: SchListOfBSTRs, o_l_images: SchListOfObjects) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppListImages(SchListOfBSTRs iLFilter,
                | SchListOfObjects oLImages)
                | 
                |     List the images of this master object.
                | 
                |     Parameters:
                | 
                |         iLFilter
                |             A list of image class names for filtering (can be NULL).
                |             
                |         oLUKImages
                |             A list of image pointers (a list of CATIASchAppMultiImage
                |             pointers). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppMultiImageMaster
                |          Dim objLFilter As SchListOfBSTRs
                |          Dim objLImages As SchListOfObjects
                |           ...
                |          objThisIntf.AppListImages objLFilter,objLImages

        :param SchListOfBSTRs i_l_filter:
        :param SchListOfObjects o_l_images:
        :rtype: None
        """
        return self.sch_app_multi_image_master.AppListImages(i_l_filter.com_object, o_l_images.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_list_images'
        # # vba_code = """
        # # Public Function app_list_images(sch_app_multi_image_master)
        # #     Dim iLFilter (2)
        # #     sch_app_multi_image_master.AppListImages iLFilter
        # #     app_list_images = iLFilter
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppMultiImageMaster(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_model import AnalysisModel
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AnalysisModels(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnalysisModels
                | 
                | The collection of analysis models making an analysis document.
                | As of today this collection is made of a single analysis
                | model.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AnalysisModel)
        self.analysis_models = com_object

    def item(self, i_index: cat_variant) -> AnalysisModel:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As AnalysisModel
                | 
                |     Returns an analysis model using its index or its name from the analysis
                |     model collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the analysis model to retrieve from the
                |             collection of analysis model. As a numerics, this index is the rank of the
                |             analysis model in the collection. The index of the first analysis model in the
                |             collection is 1, and the index of the last analysis model is Count. As a
                |             string, it is the name you assigned to the analysis model using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved analysis model 
                |     Example:
                |         The following example retrieves the first analysis model in the
                |         analysis model collection of the AnalysisManager
                |         object.
                | 
                |          Dim AnalysisDocument As Document
                |          Set AnalysisDocument = CATIA.ActiveDocument
                |          Dim RootAnalysis As AnalysisManager
                |          Set RootAnalysis = AnalysisDocument.Analysis
                |          Dim analysisModels As AnalysisModels
                |          Set analysisModels = RootAnalysis.AnalysisModels
                |          Dim analysisModel As AnalysisModel
                |          Set AnalysisModel = analysisModel.Item(1)

        :param cat_variant i_index:
        :rtype: AnalysisModel
        """
        return AnalysisModel(self.analysis_models.Item(i_index))

    def __repr__(self):
        return f'AnalysisModels(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.part_interfaces.defeaturing_filters import DefeaturingFilters
from pycatia.part_interfaces.dress_up_shape import DressUpShape


class Defeaturing(DressUpShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             Defeaturing
                | 
                | Represents the defeaturing.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.defeaturing = com_object

    @property
    def filters(self) -> DefeaturingFilters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Filters() As DefeaturingFilters (Read Only)
                | 
                |     Returns the filter collection of the Defeaturing. The returned object is
                |     the filter collection associated to this Defeaturing object. All changes
                |     applied to the returned collection will be automatically applied to the
                |     Defeaturing object. As a consequence there is no need to affect the collection
                |     to the defeaturing after the change to update the
                |     property.
                | 
                |     Returns:
                |         oFilters The filter collection (see DefeaturingFilters for list of
                |         possible actions)
                | 
                |         Example:
                |             The following example returns in myDefeaturingFiltersCollection the
                |             filter collection of the Defeaturing
                |             firstDefeaturing:
                | 
                |              Set myDefeaturingFiltersCollection = firstDefeaturing.Filters

        :rtype: DefeaturingFilters
        """

        return DefeaturingFilters(self.defeaturing.Filters)

    def __repr__(self):
        return f'Defeaturing(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.repartition import Repartition


class LinearRepartition(Repartition):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PartInterfaces.Repartition
                |                         LinearRepartition
                | 
                | Represents the linear repartition.
                | It is used by the rectangular and circular patterns. It is made up of a number
                | of times the shape is copied and of a spacing distance between two consecutive
                | copies of this shape along a direction. The number of times the shape is copied
                | is accessible using the Repartition.InstancesCount property.
                | 
                | See also:
                |     RectPattern, CircPattern
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.linear_repartition = com_object

    @property
    def spacing(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Spacing() As Length (Read Only)
                | 
                |     Returns the distance between two consecutive shapes along the repartition
                |     direction.
                | 
                |     Example:
                |         The following example returns in space1 the spacing distance of the
                |         linear repartition firstRepartition:
                | 
                |          Set space1 = firstRepartition.Spacing

        :rtype: Length
        """

        return Length(self.linear_repartition.Spacing)

    def __repr__(self):
        return f'LinearRepartition(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.product_structure_interfaces.product import Product


class UserSurface(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     UserSurface

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.user_surface = com_object

    def add_reference(self, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddReference(Reference iSupport)
                | 
                |     Add a surface in a User Surface Support
                | 
                |     Parameters:
                | 
                |         iSupport
                |             The surface that you want to add in the User
                |             Surface.

        :param Reference i_support:
        :rtype: None
        """
        return self.user_surface.AddReference(i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_reference'
        # # vba_code = """
        # # Public Function add_reference(user_surface)
        # #     Dim iSupport (2)
        # #     user_surface.AddReference iSupport
        # #     add_reference = iSupport
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_reference_in_a_product_ctx(self, i_prod_inst: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddReferenceInAProductCtx(Product iProdInst,
                | Reference iSupport)
                | 
                |     Add a surface in a User Surface Support
                | 
                |     Parameters:
                | 
                |         iProdInst
                |             The product instance where there is the geometry. 
                |         iSupport
                |             The surface that you want to add in the User
                |             Surface.

        :param Product i_prod_inst:
        :param Reference i_support:
        :rtype: None
        """
        return self.user_surface.AddReferenceInAProductCtx(i_prod_inst.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_reference_in_a_product_ctx'
        # # vba_code = """
        # # Public Function add_reference_in_a_product_ctx(user_surface)
        # #     Dim iProdInst (2)
        # #     user_surface.AddReferenceInAProductCtx iProdInst
        # #     add_reference_in_a_product_ctx = iProdInst
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_user_surface(self, i_user_surf: 'UserSurface') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddUserSurface(UserSurface iUserSurf)
                | 
                |     Add a User Surface Support in a User Surface Node
                | 
                |     Parameters:
                | 
                |         iUserSurf
                |             The User Surface Support that you want to add in the User
                |             Surface.

        :param UserSurface i_user_surf:
        :rtype: None
        """
        return self.user_surface.AddUserSurface(i_user_surf.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_user_surface'
        # # vba_code = """
        # # Public Function add_user_surface(user_surface)
        # #     Dim iUserSurf (2)
        # #     user_surface.AddUserSurface iUserSurf
        # #     add_user_surface = iUserSurf
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'UserSurface(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.arrangement_interfaces.arr_nomenclatures import ArrNomenclatures


class ArrNomenclature(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrNomenclature
                | 
                | Represents the UserNomenclature object.
                | The UserNomenclature object is used in the CATIAArrNomenclatureTree object to
                | maintain the hierarchy of user type names and associated icons.
                | CATIAArrNomenclatureTree
                |
                | _______ Area - (I_ArrArea)
                |
                | _______ Building -
                | (I_ArrBuilding)
                |
                | _______ Safety Zone - (I_ArrSafetyZone)
                |
                | -------- Run -
                | (I_ArrRun)
                |
                | _______ Conduit Run
                | _______ Raceway Run In the diagram shown
                | above, Area (along with its subtypes) and Run (also along with it's
                | subtypes) are all UserNomenclature objects. Entries such as the Area and Run
                | are called System or SuperClass objects that have to be defined first before
                | the subclasses such as Building and Safety Zone are defined. SuperClasses will
                | not have a supertype. Each Nomenclature holds the following information... (1)
                | NLSName - So as to support names in different languages (2) IconName - So as to
                | allow user's to define their own icons (3) SuperType - For subtypes to fetch
                | their parent names (4) SubTypes - SubTypes defined under this User
                | Nomenclature
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arr_nomenclature = com_object

    @property
    def icon_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IconName() As CATBSTR
                | 
                |     Gets/Sets the Icon Name associated to the Type Name. The IconName is the
                |     file name, without the extension, of the Icon bitmap representing this user
                |     type. The icon definition file must be in one of the icon directories defined
                |     in the search paths used by CATIA.

        :rtype: str
        """

        return self.arr_nomenclature.IconName

    @icon_name.setter
    def icon_name(self, value: str):
        """
        :param str value:
        """

        self.arr_nomenclature.IconName = value

    @property
    def int_sys_class_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IntSysClassName() As CATBSTR
                | 
                |     Gets/Sets the internal class names for System nomenclatures. This value is
                |     set only for System nomenclatures

        :rtype: str
        """

        return self.arr_nomenclature.IntSysClassName

    @int_sys_class_name.setter
    def int_sys_class_name(self, value: str):
        """
        :param str value:
        """

        self.arr_nomenclature.IntSysClassName = value

    @property
    def nls_instance_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NLSInstanceName() As CATBSTR
                | 
                |     Gets/Sets the InstanceName

        :rtype: str
        """

        return self.arr_nomenclature.NLSInstanceName

    @nls_instance_name.setter
    def nls_instance_name(self, value: str):
        """
        :param str value:
        """

        self.arr_nomenclature.NLSInstanceName = value

    @property
    def sub_types(self) -> 'ArrNomenclatures':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SubTypes() As ArrNomenclatures (Read Only)
                | 
                |     Returns the collection of subtype UserNomenclatures within this
                |     UserNomenclature.

        :rtype: ArrNomenclatures
        """
        from pycatia.arrangement_interfaces.arr_nomenclatures import ArrNomenclatures
        return ArrNomenclatures(self.arr_nomenclature.SubTypes)

    @property
    def super_type_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SuperTypeName() As CATBSTR
                | 
                |     Get/Set the Supertype Information This property is used to set the subtypes
                |     for system classes

        :rtype: str
        """

        return self.arr_nomenclature.SuperTypeName

    @super_type_name.setter
    def super_type_name(self, value: str):
        """
        :param str value:
        """

        self.arr_nomenclature.SuperTypeName = value

    def is_system_nomenclature(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsSystemNomenclature() As boolean
                | 
                |     Returns TRUE if the nomenclature happens to be a system nomenclature.
                |     Returns FALSE if it is a user specified nomenclature.

        :rtype: bool
        """
        return self.arr_nomenclature.IsSystemNomenclature()

    def __repr__(self):
        return f'ArrNomenclature(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_boundary_condition import ABQBoundaryCondition


class ABQTemperatureBC(ABQBoundaryCondition):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQBoundaryCondition
                |                         ABQTemperatureBC
                | 
                | Represents an Abaqus Temperature boundary condition (ABQTemperatureBC)
                | feature.
                | Role:Access an Abaqus Temperature boundary condition feature or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_temperature_bc = com_object

    @property
    def magnitude(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Magnitude() As double
                | 
                |     Sets or returns the magnitude of the temperature boundary
                |     condition.
                | 
                |     Returns:
                |         The magnitude of the temperature boundary condition.

        :rtype: float
        """

        return self.abq_temperature_bc.Magnitude

    @magnitude.setter
    def magnitude(self, value: float):
        """
        :param float value:
        """

        self.abq_temperature_bc.Magnitude = value

    @property
    def use_amplitude(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseAmplitude() As boolean
                | 
                |     Sets or returns the UseAmplitude flag.
                | 
                |     Returns:
                |         A boolean specifying whether an amplitude will be
                |         used.

        :rtype: bool
        """

        return self.abq_temperature_bc.UseAmplitude

    @use_amplitude.setter
    def use_amplitude(self, value: bool):
        """
        :param bool value:
        """

        self.abq_temperature_bc.UseAmplitude = value

    def __repr__(self):
        return f'ABQTemperatureBC(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.sketcher_interfaces.curve_2D import Curve2D
from pycatia.sketcher_interfaces.point_2D import Point2D
from pycatia.system_interfaces.system_service import SystemService


class Circle2D(Curve2D):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SketcherInterfaces.GeometricElement
                |                         SketcherInterfaces.Geometry2D
                |                             SketcherInterfaces.Curve2D
                |                                 Circle2D
                | 
                | Class defining a circle in 2D Space.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.circle_2d = com_object

    @property
    def center_point(self) -> Point2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CenterPoint() As Point2D
                | 
                |     Returns the center point of the circle.
                | 
                |     Parameters:
                | 
                |         oCenterPoint
                |             The center point of the circle

        :rtype: Point2D
        """

        return Point2D(self.circle_2d.CenterPoint)

    @center_point.setter
    def center_point(self, value: Point2D):
        """
        :param Point2D value:
        """

        self.circle_2d.CenterPoint = value

    @property
    def radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As double (Read Only)
                | 
                |     Returns the radius of the circle
                | 
                |     Parameters:
                | 
                |         oRadius
                |             The radius of the circle

        :rtype: float
        """

        return self.circle_2d.Radius

    def get_center(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCenter(CATSafeArrayVariant oData)
                | 
                |     Returns the center of the circle
                | 
                |     Parameters:
                | 
                |         oData[0]
                |             The X Coordinate of the circle center point 
                |         oData[1]
                |             The Y Coordinate of the circle center point 
                |         Example:
                |             The following example reads the coordinates of the
                |             center
                |             of the circle myCircle: double center(1) myCircle.GetCenter
                |             center

        :rtype: tuple
        """

        vba_function_name = 'get_center'
        vba_code = """
        Public Function get_center(circle2_d)
            Dim oData (2)
            circle2_d.GetCenter oData
            get_center = oData
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_data(self, i_center_x: float, i_center_y: float, i_radius: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetData(double iCenterX,
                | double iCenterY,
                | double iRadius)
                | 
                |     Modifies the caracteristics of the circle
                | 
                |     Parameters:
                | 
                |         iCenterX
                |             The X Coordinate of the circle center 
                |         iCenterY
                |             The Y Coordinate of the circle center 
                |         iRadius
                |             The radius of the circle

        :param float i_center_x:
        :param float i_center_y:
        :param float i_radius:
        :rtype: None
        """
        return self.circle_2d.SetData(i_center_x, i_center_y, i_radius)

    def __repr__(self):
        return f'Circle2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_boundary_conditions import ABQBoundaryConditions
from pycatia.abq_automation_interfaces.abq_fields import ABQFields
from pycatia.abq_automation_interfaces.abq_loads import ABQLoads
from pycatia.abq_automation_interfaces.abq_step import ABQStep


class ABQExplicitDynamicsStep(ABQStep):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQStep
                |                         ABQExplicitDynamicsStep
                | 
                | Represents an Abaqus explicit dynamics step (ABQExplicitDynamicsStep)
                | object.
                | Role: Access an Abaqus explicit dynamics step object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_explicit_dynamics_step = com_object

    @property
    def auto_time_increment_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutoTimeIncrementMethod() As
                | AutoTimeIncrementMethod
                | 
                |     Sets or returns the automatic time increment estimator method. Applies only
                |     when TimeIncrementationMethod is AUTO_INCREMENT.
                | 
                |       
                |     Legal values:
                |         ABQ_ATI_GLOBAL
                |         ABQ_ATI_ELEMENT_BY_ELEMENT

        :return: enum auto_time_increment_method
        :rtype: int
        """

        return self.abq_explicit_dynamics_step.AutoTimeIncrementMethod

    @auto_time_increment_method.setter
    def auto_time_increment_method(self, value: int):
        """
        :param int value: enum auto_time_increment_method
        """

        self.abq_explicit_dynamics_step.AutoTimeIncrementMethod = value

    @property
    def boundary_conditions(self) -> ABQBoundaryConditions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BoundaryConditions() As ABQBoundaryConditions (Read
                | Only)
                | 
                |     Returns the ABQBoundaryConditions container associated with the
                |     step.
                | 
                |     Example:
                |         This example retrieves the ABQBoundaryConditions container
                |         abqBCs.
                | 
                |          Dim abqStep As ABQExplicitDynamicsStep 
                |          Dim abqBCs As ABQBoundaryConditions
                |          Set abqBCs = abqStep.BoundaryConditions

        :rtype: ABQBoundaryConditions
        """

        return ABQBoundaryConditions(self.abq_explicit_dynamics_step.BoundaryConditions)

    @property
    def description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As CATBSTR
                | 
                |     Sets or returns the description of the Abaqus explicit dynamics
                |     step.
                | 
                |     Returns:
                |         The description of the Abaqus explicit dynamics step.

        :rtype: str
        """

        return self.abq_explicit_dynamics_step.Description

    @description.setter
    def description(self, value: str):
        """
        :param str value:
        """

        self.abq_explicit_dynamics_step.Description = value

    @property
    def fields(self) -> ABQFields:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Fields() As ABQFields (Read Only)
                | 
                |     Returns the ABQFields container associated with the step.
                | 
                |     Example:
                |         This example retrieves the ABQFields container
                |         abqFields.
                | 
                |          Dim abqStep As ABQExplicitDynamicsStep 
                |          Dim abqFields As ABQFields
                |          Set abqFields = abqStep.Fields

        :rtype: ABQFields
        """

        return ABQFields(self.abq_explicit_dynamics_step.Fields)

    @property
    def fixed_time_increment_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FixedTimeIncrementMethod() As
                | FixedTimeIncrementMethod
                | 
                |     Sets or returns the fixed time increment method. Applies only when
                |     TimeIncrementationMethod is FIXED_INCREMENT. If the method is set to
                |     ABQ_FTI_USER_DEFINED, the UserDefinedTimeIncrementValue property must be set to
                |     specifiy the time increment value.

        :return: enum fixed_time_increment_method
        :rtype: int
        """

        return self.abq_explicit_dynamics_step.FixedTimeIncrementMethod

    @fixed_time_increment_method.setter
    def fixed_time_increment_method(self, value: int):
        """
        :param int value: enum fixed_time_increment_method
        """

        self.abq_explicit_dynamics_step.FixedTimeIncrementMethod = value

    @property
    def loads(self) -> ABQLoads:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Loads() As ABQLoads (Read Only)
                | 
                |     Returns the ABQLoads container associated with the step.
                | 
                |     Example:
                |         The following example retrieves the ABQLoads container
                |         abqLoads:
                | 
                |          Dim abqStep As ABQExplicitDynamicsStep 
                |          Dim abqLoads As ABQLoads
                |          Set abqLoads = abqStep.Loads

        :rtype: ABQLoads
        """

        return ABQLoads(self.abq_explicit_dynamics_step.Loads)

    @property
    def maximum_time_increment_limit(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaximumTimeIncrementLimit() As double
                | 
                |     Sets or returns the maximum time increment limit. Applies only when
                |     TimeIncrementationMethod is AUTO_INCREMENT. Zero specifies that the maximum
                |     time increment is unlimited.
                | 
                |     Returns:
                |         The maximum time increment limit.

        :rtype: float
        """

        return self.abq_explicit_dynamics_step.MaximumTimeIncrementLimit

    @maximum_time_increment_limit.setter
    def maximum_time_increment_limit(self, value: float):
        """
        :param float value:
        """

        self.abq_explicit_dynamics_step.MaximumTimeIncrementLimit = value

    @property
    def nl_geom(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NLGeom() As boolean
                | 
                |     Sets or returns whether the geometry remains linear during the analysis. A
                |     value of true indicates that the geometry remains linear.
                | 
                |     Returns:
                |         A boolean specifying whether the geometry remains linear during the
                |         analysis.

        :rtype: bool
        """

        return self.abq_explicit_dynamics_step.NLGeom

    @nl_geom.setter
    def nl_geom(self, value: bool):
        """
        :param bool value:
        """

        self.abq_explicit_dynamics_step.NLGeom = value

    @property
    def time_incrementation_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimeIncrementationMethod() As Incrementation_Type
                | 
                |     Sets or returns the type of the incrementation during the
                |     step.
                | 
                |     Returns:
                |         The type of the incrementation
                | 
                |           
                |         Legal values:
                |           AUTO_INCREMENT
                |           FIXED_INCREMENT

        :return: enum incrementation_type
        :rtype: int
        """

        return self.abq_explicit_dynamics_step.TimeIncrementationMethod

    @time_incrementation_method.setter
    def time_incrementation_method(self, value: int):
        """
        :param int value: enum incrementation_type
        """

        self.abq_explicit_dynamics_step.TimeIncrementationMethod = value

    @property
    def time_period(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimePeriod() As double
                | 
                |     Sets or returns the total time period of the Abaqus explicit dynamics
                |     step.
                | 
                |     Returns:
                |         The total time period of the Abaqus explicit dynamics step.

        :rtype: float
        """

        return self.abq_explicit_dynamics_step.TimePeriod

    @time_period.setter
    def time_period(self, value: float):
        """
        :param float value:
        """

        self.abq_explicit_dynamics_step.TimePeriod = value

    @property
    def time_scaling_factor(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimeScalingFactor() As double
                | 
                |     Sets or returns the time scaling factor.

        :rtype: float
        """

        return self.abq_explicit_dynamics_step.TimeScalingFactor

    @time_scaling_factor.setter
    def time_scaling_factor(self, value: float):
        """
        :param float value:
        """

        self.abq_explicit_dynamics_step.TimeScalingFactor = value

    @property
    def user_defined_time_increment_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UserDefinedTimeIncrementValue() As double
                | 
                |     Sets or returns the user-defined time increment value. Applies only when
                |     FixedTimeIncrementMethod is set to ABQ_FTI_USER_DEFINED.

        :rtype: float
        """

        return self.abq_explicit_dynamics_step.UserDefinedTimeIncrementValue

    @user_defined_time_increment_value.setter
    def user_defined_time_increment_value(self, value: float):
        """
        :param float value:
        """

        self.abq_explicit_dynamics_step.UserDefinedTimeIncrementValue = value

    def __repr__(self):
        return f'ABQExplicitDynamicsStep(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class Fastener(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Fastener

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.fastener = com_object

    def all_parts_loaded(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AllPartsLoaded() As boolean
                | 
                |     Gets the loading status of the joining parts of the fastener If all the joining parts are
                |     loaded in the V5 session then it returns TRUE If no parts or some parts are loaded in the
                |     V5 session then it returns FALSE Return type : 1,0
                | 
                | Example:
                |     Dim AllPartsLoaded AllPartsLoaded = MyFastener.AllPartsLoaded

        :rtype: bool
        """
        return self.fastener.AllPartsLoaded()

    def get_double_user_attribute(self, i_attribute_label: str) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDoubleUserAttribute(CATBSTR iAttributeLabel) As
                | double
                | 
                |     Returns the value of user attribute whoes name matches the
                |     input
                |     string. Valid for attributes of type double. User attributes
                |     are
                |     created from Process Engineer user attributes only.
                | 
                |     Parameters:
                | 
                |         iAttributeLabel
                |             The label of user attribute of double type 
                | 
                |     Example:
                |         This example gets value of double user attribute "PLATE SIZE" on
                |         Process Engineer fastener
                | 
                |          DblAttrVal = MyFastener.GetDoubleUserAttribute ("PLATE SIZE")

        :param str i_attribute_label:
        :rtype: float
        """
        return self.fastener.GetDoubleUserAttribute(i_attribute_label)

    def get_int_user_attribute(self, i_attribute_label: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetIntUserAttribute(CATBSTR iAttributeLabel) As long

        :param str i_attribute_label:
        :rtype: int
        """
        return self.fastener.GetIntUserAttribute(i_attribute_label)

    def get_part(self, index: int) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPart(short index) As Product
                | 
                |     Returns the product at the specified index from list of parts joined by
                |     fastener.
                | 
                |     Parameters:
                | 
                |         index
                |             Index should be greater than equal to 1. 
                | 
                |     Example:
                |         This example gets the part at index 1
                | 
                |          Dim MyProduct As Product
                |          Set MyProduct = MyFastener.GetPart(1)

        :param int index:
        :rtype: Product
        """
        return Product(self.fastener.GetPart(index))

    def get_parts(self, o_list_of_parts: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetParts(CATSafeArrayVariant oListOfParts)
                | 
                |     Returns the list of parts joined by fastener.
                | 
                |     Parameters:
                | 
                |         oListOfParts
                |             The list of parts 
                | 
                |     Example:
                |         This example gets list of parts joined by fastener
                | 
                |          Dim NumberOfParts
                |          Dim JoiningParts()
                |          NumberOfParts = MyFastener.NumberOfJoiningParts
                |          ReDim JoiningParts(NumParts-1)
                |          MyFastener.GetParts(JoiningParts)

        :param tuple o_list_of_parts:
        :rtype: None
        """
        return self.fastener.GetParts(o_list_of_parts)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_parts'
        # # vba_code = """
        # # Public Function get_parts(fastener)
        # #     Dim oListOfParts (2)
        # #     fastener.GetParts oListOfParts
        # #     get_parts = oListOfParts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_process(self, index: int) -> Activity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProcess(short index) As Activity
                | 
                |     Returns the activity, at the specified index, on which the fastener is
                |     assigned
                | 
                |     Parameters:
                | 
                |         index
                |             Index should be greater than equal to 1. 
                | 
                |     Example:
                |         This example gets the activity at index 1
                | 
                |          Dim MyActivity As Activity
                |          Set MyActivity = MyFastener.GetProcess(1)

        :param int index:
        :rtype: Activity
        """
        return Activity(self.fastener.GetProcess(index))

    def get_string_user_attribute(self, i_attribute_label: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStringUserAttribute(CATBSTR iAttributeLabel) As
                | CATBSTR
                | 
                |     Returns the value of user attribute whoes name matches the
                |     input
                |     string. Valid for attributes of type string. User attributes
                |     are
                |     created from Process Engineer user attributes only.
                | 
                |     Parameters:
                | 
                |         iAttributeLabel
                |             The label of user attribute of string type 
                | 
                |     Example:
                |         This example gets value of string user attribute "PLATE NAME" on
                |         Process Engineer fastener
                | 
                |          Dim StrAttrVal As String
                |          StrAttrVal = MyFastener.GetStringUserAttribute ("PLATE NAME")

        :param str i_attribute_label:
        :rtype: str
        """
        return self.fastener.GetStringUserAttribute(i_attribute_label)

    def number_of_assigned_processes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func NumberOfAssignedProcesses() As long
                | 
                |     Returns Number of processes assigned with the fastener 
                | 
                | Example:
                |     Dim Num Num = MyFastener.NumberOfAssignedProcesses

        :rtype: int
        """
        return self.fastener.NumberOfAssignedProcesses()

    def number_of_joining_parts(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func NumberOfJoiningParts() As long
                | 
                |     Returns the number of parts joined by fastener.
                | 
                |     Parameters:
                | 
                |         oNumOfParts
                |             The number of parts 
                | 
                |     Example:
                |         This example gets number of parts joined by fastener
                | 
                |          Dim NumberOfParts
                |          NumberOfParts = MyFastener.NumberOfJoiningParts

        :rtype: int
        """
        return self.fastener.NumberOfJoiningParts()

    def remove_from_ppr(self, i_force_remove_if_assigned: bool, e_status: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveFromPPR(boolean iForceRemoveIfAssigned,
                | DNBPPRRemoveStatus eStatus)
                | 
                |     Removes the fastener from the current session without deleting it in the
                |     Manufacturing HUB project.
                | 
                |     Parameters:
                | 
                |         in
                |             iForceRemoveIfAssigned Valid Param : 1 : for removing fastener from session even in
                |             case it is assigned to a process or resource. The product/resource to fastener relation
                |             remains un-affected in PPRHUB. 0 : for NOT removing the fastener from session in case it
                |             is assigned to a process or resource.
                |         out
                |             eStatus Status of remove call. See DNBPPRRemoveStatus definition
                |             above. * 
                | 
                |     Example:
                |         Dim RemoveStatus As EnumParam MyFastenerPPRServices.RemoveFromPPR 1,
                |         RemoveStatus MsgBox RemoveStatus

        :param bool i_force_remove_if_assigned:
        :param int e_status: enum dnbppr_remove_status
        :rtype: None
        """
        return self.fastener.RemoveFromPPR(i_force_remove_if_assigned, e_status)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_from_ppr'
        # # vba_code = """
        # # Public Function remove_from_ppr(fastener)
        # #     Dim iForceRemoveIfAssigned (2)
        # #     fastener.RemoveFromPPR iForceRemoveIfAssigned
        # #     remove_from_ppr = iForceRemoveIfAssigned
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_double_user_attribute(self, i_attribute_label: str, i_double_value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDoubleUserAttribute(CATBSTR iAttributeLabel,
                | double iDoubleValue)
                | 
                |     Set the value of user attribute whoes name matches the
                |     input
                |     string. Valid for attributes of type double. User attributes
                |     are
                |     created from Process Engineer user attributes only.
                | 
                |     Parameters:
                | 
                |         iAttributeLabel
                |             The label of user attribute of double type 
                | 
                |     Example:
                |         This example gets value of double user attribute "PLATE SIZE" on
                |         Process Engineer fastener
                | 
                |          MyFastener.GetDoubleUserAttribute ("PLATE SIZE",DblAttrVal)

        :param str i_attribute_label:
        :param float i_double_value:
        :rtype: None
        """
        return self.fastener.SetDoubleUserAttribute(i_attribute_label, i_double_value)

    def set_int_user_attribute(self, i_attribute_label: str, i_int_value: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetIntUserAttribute(CATBSTR iAttributeLabel,
                | long iIntValue)

        :param str i_attribute_label:
        :param int i_int_value:
        :rtype: None
        """
        return self.fastener.SetIntUserAttribute(i_attribute_label, i_int_value)

    def set_string_user_attribute(self, i_attribute_label: str, i_string_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStringUserAttribute(CATBSTR iAttributeLabel,
                | CATBSTR iStringValue)
                | 
                |     Set the value of user attribute whoes name matches the
                |     input
                |     string. Valid for attributes of type string. User attributes
                |     are
                |     created from Process Engineer user attributes only.
                | 
                |     Parameters:
                | 
                |         iAttributeLabel
                |             The label of user attribute of string type 
                | 
                |     Example:
                |         This example gets value of string user attribute "PLATE NAME" on
                |         Process Engineer fastener
                | 
                |          Dim StrAttrVal As String
                |          StrAttrVal = "Name"
                |          MyFastener.SetStringUserAttribute ("PLATE NAME",StrAttrVal)

        :param str i_attribute_label:
        :param str i_string_value:
        :rtype: None
        """
        return self.fastener.SetStringUserAttribute(i_attribute_label, i_string_value)

    def set_text_id_visibility(self, i_status: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTextIDVisibility(boolean iStatus)
                | 
                |     Sets the Hide/Show status of the text ID of the fastener in the 3D window Valid Param : 1,0 
                | 
                | Example:
                |     //to make the fastener id visible in 3D MyFastener.SetIDVisibility(1) //to
                |     make the fastener id hidden in 3D
                |     MyFastener.SetIDVisibility(0)
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :param bool i_status:
        :rtype: None
        """
        return self.fastener.SetTextIDVisibility(i_status)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_text_id_visibility'
        # # vba_code = """
        # # Public Function set_text_id_visibility(fastener)
        # #     Dim iStatus (2)
        # #     fastener.SetTextIDVisibility iStatus
        # #     set_text_id_visibility = iStatus
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Fastener(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_rsc_interfaces.rendering_environment import RenderingEnvironment
from pycatia.cat_rsc_interfaces.rendering_light import RenderingLight
from pycatia.in_interfaces.camera_3d import Camera3D
from pycatia.system_interfaces.any_object import AnyObject


class RenderingShooting(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     RenderingShooting
                | 
                | Represents a Material object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rendering_shooting = com_object

    @property
    def active_camera(self) -> Camera3D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveCamera() As Camera3D
                | 
                |     Returns or sets the active camera for shooting. A shooting can only have
                |     one active camera at a time.

        :rtype: Camera3D
        """

        return Camera3D(self.rendering_shooting.ActiveCamera)

    @active_camera.setter
    def active_camera(self, value: Camera3D):
        """
        :param Camera3D value:
        """

        self.rendering_shooting.ActiveCamera = value

    @property
    def active_environment(self) -> RenderingEnvironment:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveEnvironment() As RenderingEnvironment
                | 
                |     Returns or sets the active environment for shooting.
                |     A shooting can have one or zero active environment at a time.

        :rtype: RenderingEnvironment
        """

        return RenderingEnvironment(self.rendering_shooting.ActiveEnvironment)

    @active_environment.setter
    def active_environment(self, value: RenderingEnvironment):
        """
        :param RenderingEnvironment value:
        """

        self.rendering_shooting.ActiveEnvironment = value

    @property
    def ambient_factor(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AmbientFactor() As short
                | 
                |     Returns or sets amount of ambient used for indirect illumination (final
                |     gathering or global illumination).
                |     The ambient factor can be:
                |     1: Ambient is taken into account
                |     0: No ambient used

        :rtype: int
        """

        return self.rendering_shooting.AmbientFactor

    @ambient_factor.setter
    def ambient_factor(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.AmbientFactor = value

    @property
    def antialiasing_contrast(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AntialiasingContrast() As short
                | 
                |     Returns or sets the antialiasing contrast threshold value.
                |     This value ranges from 0. to 100.%. Contrast value sets the contrast
                |     threshold for adaptative oversampling, that is, the maximum contrast threshold
                |     between pixels, below which no oversampling will be done.
                |     If the contrast of any RGB component between the currently calculated pixel
                |     and heighboring pixels weighted by their sum is greater than this threshold,
                |     the pixel is oversampled.

        :rtype: int
        """

        return self.rendering_shooting.AntialiasingContrast

    @antialiasing_contrast.setter
    def antialiasing_contrast(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.AntialiasingContrast = value

    @property
    def antialiasing_max_sample(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AntialiasingMaxSample() As short
                | 
                |     Returns or sets the antialiasing maximum sample number for image
                |     computation.
                |     This value ranges from 0/code> to 5/code>.
                |     Maximum samples value sets the minimum number of rays casted for 1,4 or 16
                |     pixels.
                | 
                |         The possible maximum sample number are:
                |         0 : 1 ray casted for a 4x4 pixel square
                |         1 : 1 ray casted for a 2x2 pixel square
                |         2 : 1 ray casted per pixel
                |         3 : 4 rays casted per pixel
                |         4 : 16 rays casted per pixel
                |         5 : 64 rays casted per pixel

        :rtype: int
        """

        return self.rendering_shooting.AntialiasingMaxSample

    @antialiasing_max_sample.setter
    def antialiasing_max_sample(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.AntialiasingMaxSample = value

    @property
    def antialiasing_min_sample(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AntialiasingMinSample() As short
                | 
                |     Returns or sets the antialiasing minimum sample number for image
                |     computation.
                |     This value ranges from 0/code> to 5/code>.
                |     Minimum samples value sets the minimum number of rays casted for 1,4 or 16
                |     pixels.
                | 
                |         The possible minimum sample number are:
                |         0 : 1 ray casted for a 4x4 pixel square
                |         1 : 1 ray casted for a 2x2 pixel square
                |         2 : 1 ray casted per pixel
                |         3 : 4 rays casted per pixel
                |         4 : 16 rays casted per pixel
                |         5 : 64 rays casted per pixel

        :rtype: int
        """

        return self.rendering_shooting.AntialiasingMinSample

    @antialiasing_min_sample.setter
    def antialiasing_min_sample(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.AntialiasingMinSample = value

    @property
    def cartoon_contour_thickness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CartoonContourThickness() As double
                | 
                |     Returns or sets the cartoon contour thickness.
                |     The line thickness is given as image size percentage.
                |     The line thickness ranges from 0.0 (none) to 100.0.

        :rtype: float
        """

        return self.rendering_shooting.CartoonContourThickness

    @cartoon_contour_thickness.setter
    def cartoon_contour_thickness(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.CartoonContourThickness = value

    @property
    def cartoon_shading_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CartoonShadingStatus() As short
                | 
                |     Returns or sets the cartoon shading status of shooting.
                |     This status defines if the cartoon shading is activated or
                |     not.
                |     If shading is deactivated, only contours are rendered.
                |     The cartoon shading effect status can be:
                |     1: Shading status is active
                |     0: Shading status is deactivated

        :rtype: int
        """

        return self.rendering_shooting.CartoonShadingStatus

    @cartoon_shading_status.setter
    def cartoon_shading_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.CartoonShadingStatus = value

    @property
    def cartoon_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CartoonStatus() As short
                | 
                |     Returns or sets the cartoon status of shooting.
                |     This status defines if the cartoon rendering is activated or
                |     not.
                |     The cartoon effect status can be:
                |     1: Cartoon status is active
                |     0: Cartoon status is deactivated

        :rtype: int
        """

        return self.rendering_shooting.CartoonStatus

    @cartoon_status.setter
    def cartoon_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.CartoonStatus = value

    @property
    def cartoon_stroke_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CartoonStrokeStatus() As short
                | 
                |     Returns or sets the cartoon stroke status of shooting.
                |     This status defines if the cartoon stroke effect (ink pen effect) is
                |     activated or not.
                |     The stroke status can be:
                |     1: Stroke status is active
                |     0: Stroke status is deactivated

        :rtype: int
        """

        return self.rendering_shooting.CartoonStrokeStatus

    @cartoon_stroke_status.setter
    def cartoon_stroke_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.CartoonStrokeStatus = value

    @property
    def caustic_accuracy(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CausticAccuracy() As short
                | 
                |     Returns or sets the number of photons to use when estimating radiance for
                |     caustics.

        :rtype: int
        """

        return self.rendering_shooting.CausticAccuracy

    @caustic_accuracy.setter
    def caustic_accuracy(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.CausticAccuracy = value

    @property
    def caustic_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CausticRadius() As double
                | 
                |     Returns or sets the maximum distance in which photons for caustics are
                |     located.
                |     If the value is 0.0 an estimate based on the scene extent will be used.

        :rtype: float
        """

        return self.rendering_shooting.CausticRadius

    @caustic_radius.setter
    def caustic_radius(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.CausticRadius = value

    @property
    def caustic_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CausticStatus() As short
                | 
                |     Returns or sets the caustic status of shooting.
                |     This status defines if caustics are calculated or not.
                |     The caustic status can be:
                |     1: Caustics are enabled
                |     0: Caustics are disabled

        :rtype: int
        """

        return self.rendering_shooting.CausticStatus

    @caustic_status.setter
    def caustic_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.CausticStatus = value

    @property
    def depth_of_field_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DepthOfFieldRadius() As double
                | 
                |     Returns or sets the depth of field radius of confusion.
                |     The radius of confusion ranges from 1.0 to 10.0%.

        :rtype: float
        """

        return self.rendering_shooting.DepthOfFieldRadius

    @depth_of_field_radius.setter
    def depth_of_field_radius(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.DepthOfFieldRadius = value

    @property
    def depth_of_field_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DepthOfFieldStatus() As short
                | 
                |     Returns or sets the depth of field status of shooting. This status defines
                |     if depth of field effect is activated or not.
                |     The depth of field status can be:
                |     1: Depth of field is active
                |     0: Depth of field is deactivated

        :rtype: int
        """

        return self.rendering_shooting.DepthOfFieldStatus

    @depth_of_field_status.setter
    def depth_of_field_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.DepthOfFieldStatus = value

    @property
    def final_gathering_accuracy(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FinalGatheringAccuracy() As short
                | 
                |     Returns or sets the number of rays shot in each final gather.

        :rtype: int
        """

        return self.rendering_shooting.FinalGatheringAccuracy

    @final_gathering_accuracy.setter
    def final_gathering_accuracy(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.FinalGatheringAccuracy = value

    @property
    def final_gathering_max_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FinalGatheringMaxRadius() As double
                | 
                |     Returns or sets the maximum distance in which a final gather result can be
                |     used.
                |     If the value is 0.0 an estimate based on the scene extent will be used.

        :rtype: float
        """

        return self.rendering_shooting.FinalGatheringMaxRadius

    @final_gathering_max_radius.setter
    def final_gathering_max_radius(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.FinalGatheringMaxRadius = value

    @property
    def final_gathering_min_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FinalGatheringMinRadius() As double
                | 
                |     Returns or sets the minimum distance in which a final gather result can be
                |     used.
                |     If the value is 0.0 it will be set to 10% of maximum distance.

        :rtype: float
        """

        return self.rendering_shooting.FinalGatheringMinRadius

    @final_gathering_min_radius.setter
    def final_gathering_min_radius(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.FinalGatheringMinRadius = value

    @property
    def final_gathering_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FinalGatheringStatus() As short
                | 
                |     Returns or sets the final gathering status of shooting.
                |     This status defines if final gathering is activated or
                |     not.
                |     The final gathering status can be:
                |     1: Final gathering is enabled
                |     0: Final gathering is disabled

        :rtype: int
        """

        return self.rendering_shooting.FinalGatheringStatus

    @final_gathering_status.setter
    def final_gathering_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.FinalGatheringStatus = value

    @property
    def global_illumination_accuracy(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlobalIlluminationAccuracy() As short
                | 
                |     Returns or sets the number of photons to use when estimating radiance for
                |     global illumination.

        :rtype: int
        """

        return self.rendering_shooting.GlobalIlluminationAccuracy

    @global_illumination_accuracy.setter
    def global_illumination_accuracy(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.GlobalIlluminationAccuracy = value

    @property
    def global_illumination_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlobalIlluminationRadius() As double
                | 
                |     Returns or sets the maximum distance in which photons for global
                |     illumination are located.
                |     If the value is 0.0 an estimate based on the scene extent will be used.

        :rtype: float
        """

        return self.rendering_shooting.GlobalIlluminationRadius

    @global_illumination_radius.setter
    def global_illumination_radius(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.GlobalIlluminationRadius = value

    @property
    def global_illumination_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlobalIlluminationStatus() As short
                | 
                |     Returns or sets the global illumination status of
                |     shooting.
                |     This status defines if global illumination is used or not.
                |     The global illumination status can be:
                |     1: Global illumination is enabled
                |     0: Global illumination is disabled

        :rtype: int
        """

        return self.rendering_shooting.GlobalIlluminationStatus

    @global_illumination_status.setter
    def global_illumination_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.GlobalIlluminationStatus = value

    @property
    def glow_flare_diffusion(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlowFlareDiffusion() As double
                | 
                |     Returns or sets the glow flare diffusion.
                |     The flare diffusion value ranges from 0.0 to 1.0%.

        :rtype: float
        """

        return self.rendering_shooting.GlowFlareDiffusion

    @glow_flare_diffusion.setter
    def glow_flare_diffusion(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.GlowFlareDiffusion = value

    @property
    def glow_flare_factor(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlowFlareFactor() As double
                | 
                |     Returns or sets the glow flare factor.
                |     The flare factor ranges from 0.0 to 1.0%.

        :rtype: float
        """

        return self.rendering_shooting.GlowFlareFactor

    @glow_flare_factor.setter
    def glow_flare_factor(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.GlowFlareFactor = value

    @property
    def glow_intensity(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlowIntensity() As double
                | 
                |     Returns or sets the glow intensity factor.
                |     The glow intensity factor ranges from 1.0 to 10.0%.

        :rtype: float
        """

        return self.rendering_shooting.GlowIntensity

    @glow_intensity.setter
    def glow_intensity(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.GlowIntensity = value

    @property
    def glow_radial_line_size(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlowRadialLineSize() As double
                | 
                |     Returns or sets the glow radial lines size.
                |     The lines size ranges from 0.0 (none) to 1.0 (max length).

        :rtype: float
        """

        return self.rendering_shooting.GlowRadialLineSize

    @glow_radial_line_size.setter
    def glow_radial_line_size(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.GlowRadialLineSize = value

    @property
    def glow_size(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlowSize() As double
                | 
                |     Returns or sets the glow filter size in percentage of image
                |     size.
                |     The filter size ranges from 0.1 to 1.0%.

        :rtype: float
        """

        return self.rendering_shooting.GlowSize

    @glow_size.setter
    def glow_size(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.GlowSize = value

    @property
    def glow_star_effect(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlowStarEffect() As double
                | 
                |     Returns or sets the glow star effect.
                |     The effect coefficient ranges from 0.0 (random star) to 1.0 (cross).

        :rtype: float
        """

        return self.rendering_shooting.GlowStarEffect

    @glow_star_effect.setter
    def glow_star_effect(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.GlowStarEffect = value

    @property
    def glow_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlowStatus() As short
                | 
                |     Returns or sets the glow status of shooting. This status defines if the
                |     glow effect is activated or not.
                |     The glow status can be:
                |     1: Glow is active
                |     0: Glow is deactivated

        :rtype: int
        """

        return self.rendering_shooting.GlowStatus

    @glow_status.setter
    def glow_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.GlowStatus = value

    @property
    def glow_threshold(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlowThreshold() As double
                | 
                |     Returns or sets the glow color threshold.
                |     The color threshold ranges from 0.5 to 1.5%.

        :rtype: float
        """

        return self.rendering_shooting.GlowThreshold

    @glow_threshold.setter
    def glow_threshold(self, value: float):
        """
        :param float value:
        """

        self.rendering_shooting.GlowThreshold = value

    @property
    def image_height(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImageHeight() As short
                | 
                |     Returns or sets the image height for shooting.
                |     The image height ranges from 10 to 8000 pixels.

        :rtype: int
        """

        return self.rendering_shooting.ImageHeight

    @image_height.setter
    def image_height(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.ImageHeight = value

    @property
    def image_output_directory(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImageOutputDirectory() As CATBSTR
                | 
                |     Returns or sets the output directory for image.
                |     This is the place where rendered images are saved.

        :rtype: str
        """

        return self.rendering_shooting.ImageOutputDirectory

    @image_output_directory.setter
    def image_output_directory(self, value: str):
        """
        :param str value:
        """

        self.rendering_shooting.ImageOutputDirectory = value

    @property
    def image_output_format(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImageOutputFormat() As short
                | 
                |     Returns or sets the file type used for saved image.
                | 
                |         Possible format types
                |         1 TIFF True Color (\\*.tif)
                |         2 TIFF True Color Packbits (\\*.tif)
                |         3 SGI Format (\\*.rgb)
                |         4 Windows Bitmap (\\*.bmp)
                |         5 JPEG Fair Quality (\\*.jpg)
                |         6 JPEG Medium Quality (\\*.jpg)
                |         7 JPEG High Quality (\\*.jpg)
                |         8 Apple Macintosh Format (\\*.pic)
                |         9 Adobe Photoshop Format (\\*.psd)
                |         10 Portable Network Graphics (\\*.png)
                |         11 Truevision Targa (\\*.tga)

        :rtype: int
        """

        return self.rendering_shooting.ImageOutputFormat

    @image_output_format.setter
    def image_output_format(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.ImageOutputFormat = value

    @property
    def image_output_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImageOutputName() As CATBSTR
                | 
                |     Returns or sets the output name for image (extension
                |     excluded).
                |     This is the name of saved files (with no extension).

        :rtype: str
        """

        return self.rendering_shooting.ImageOutputName

    @image_output_name.setter
    def image_output_name(self, value: str):
        """
        :param str value:
        """

        self.rendering_shooting.ImageOutputName = value

    @property
    def image_output_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImageOutputType() As short
                | 
                |     Returns or sets the image output location.
                | 
                |         Output types
                |         1 On screen
                |         2 On disk

        :rtype: int
        """

        return self.rendering_shooting.ImageOutputType

    @image_output_type.setter
    def image_output_type(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.ImageOutputType = value

    @property
    def image_predefined_ratio(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImagePredefinedRatio() As short
                | 
                |     Returns or sets the image height for shooting.
                |     Sets the image ratio to a standard predefined value. The image size keeps
                |     the same height and the image length is recalculated.
                | 
                |         Possible predefined ratio. 0 no predefined ratio
                |         1 0.708333 (A4)
                |         2 1.0 (6 x 6)
                |         3 1.25 (Standard)
                |         4 1.333333 (4 / 3)
                |         5 1.5 (24 x 36)
                |         6 1.687331 (16 mm.)
                |         7 1.777777 (16 / 9)
                |         8 1.855072 (HDTV)
                |         9 2.2 (Panavision)
                |         10 3.0 (Panorama)
                |         11 1.32 (CCD 1/2")
                |         12 1.333333 (CCD 1/4")

        :rtype: int
        """

        return self.rendering_shooting.ImagePredefinedRatio

    @image_predefined_ratio.setter
    def image_predefined_ratio(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.ImagePredefinedRatio = value

    @property
    def image_width(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImageWidth() As short
                | 
                |     Returns or sets the image width for shooting.
                |     The image width ranges from 10 to 8000 pixels.

        :rtype: int
        """

        return self.rendering_shooting.ImageWidth

    @image_width.setter
    def image_width(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.ImageWidth = value

    @property
    def raytracing_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RaytracingStatus() As short
                | 
                |     Returns or sets the the raytracing status for shooting.
                |     The raytracing status can be:
                |     1: Raytracing is active
                |     0: Raytracing is deactivated

        :rtype: int
        """

        return self.rendering_shooting.RaytracingStatus

    @raytracing_status.setter
    def raytracing_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.RaytracingStatus = value

    @property
    def rebounds_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReboundsCount() As short
                | 
                |     Returns or sets the maximum number of rebounds levels to take into account
                |     for image computation.
                |     This number ranges from 0 to 18 levels.

        :rtype: int
        """

        return self.rendering_shooting.ReboundsCount

    @rebounds_count.setter
    def rebounds_count(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.ReboundsCount = value

    @property
    def reflections_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReflectionsCount() As short
                | 
                |     Returns or sets the maximum number of reflections levels to take into
                |     account for image computation.
                |     This number ranges from 0 to 9 levels.

        :rtype: int
        """

        return self.rendering_shooting.ReflectionsCount

    @reflections_count.setter
    def reflections_count(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.ReflectionsCount = value

    @property
    def refractions_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RefractionsCount() As short
                | 
                |     Returns or sets the maximum number of refractions levels to take into
                |     account for image computation.
                |     This number ranges from 0 to 9 levels.

        :rtype: int
        """

        return self.rendering_shooting.RefractionsCount

    @refractions_count.setter
    def refractions_count(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.RefractionsCount = value

    @property
    def shadows_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShadowsStatus() As short
                | 
                |     Returns or sets the shadows status of shooting. This status defines if
                |     shadows are calculated or not.
                |     The shadows status can be:
                |     1: Shadows on
                |     0: Shadows off

        :rtype: int
        """

        return self.rendering_shooting.ShadowsStatus

    @shadows_status.setter
    def shadows_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.ShadowsStatus = value

    @property
    def textures_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TexturesStatus() As short
                | 
                |     Returns or sets the textures status of shooting. This status defines if
                |     textures are taken into account for image computation.
                |     The texture status can be:
                |     1: Textures are taking into account
                |     0: Textures are ignored

        :rtype: int
        """

        return self.rendering_shooting.TexturesStatus

    @textures_status.setter
    def textures_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_shooting.TexturesStatus = value

    def add_active_light(self, i_active_light: RenderingLight) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddActiveLight(RenderingLight iActiveLight)
                | 
                |     Adds a new active light to the shooting active lights list.

        :param RenderingLight i_active_light:
        :rtype: None
        """
        return self.rendering_shooting.AddActiveLight(i_active_light.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_active_light'
        # # vba_code = """
        # # Public Function add_active_light(rendering_shooting)
        # #     Dim iActiveLight (2)
        # #     rendering_shooting.AddActiveLight iActiveLight
        # #     add_active_light = iActiveLight
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def count_active_lights(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CountActiveLights() As short
                | 
                |     Returns the number of active light for the shooting.

        :rtype: int
        """
        return self.rendering_shooting.CountActiveLights()

    def get_active_light(self, i_index: int) -> RenderingLight:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetActiveLight(short iIndex) As RenderingLight
                | 
                |     Returns the active light of the shooting using its index.

        :param int i_index:
        :rtype: RenderingLight
        """
        return RenderingLight(self.rendering_shooting.GetActiveLight(i_index))

    def remove_active_light(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveActiveLight(short iIndex)
                | 
                |     Removes a light from the shootings active lights list.

        :param int i_index:
        :rtype: None
        """
        return self.rendering_shooting.RemoveActiveLight(i_index)

    def render(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Render()
                | 
                |     Render the shooting
                |     Caution: Product involved in rendering calculation should not be closed
                |     before the end of computation. If product is closed, calculation is
                |     interrupted.

        :rtype: None
        """
        return self.rendering_shooting.Render()

    def __repr__(self):
        return f'RenderingShooting(name="{self.name}")'
